%%% This is an article-like class using memoir
%%% Karnes Kim
%%%  public domain.
%%%
%%% ver0.013 2006/09/03 : introduce hfontsel.sty. 
%%% ver0.012 2006/09/01 : \thetitle, \theauthor undefined problem fixed.
%%% ver0.011 2006/05/02 : rename ksnamedef(false) to kscntformat
%%% ver0.01  2006/04/27 : introduce [nokorean] option requested by smcho.
%%% ver0.001 2006/03/11
%%%
\ProvidesClass{fakearticle}

%%% 옵션들
%%% nokorean : smcho 님이 요청하셔서 만든 영문용
%%% twoside : twoside
%%% openright
%%% kosection : 절 표제항의 한글화
%%% nobookmarks : 북마크 만들지 않음
%%% dvips : dvips 작업용 옵션
%%% 기타 옵션 : memoir 옵션 사용.
%%% default는 oneside, openany, kosection false, pdfbookmark임.
%%% 
%%% 한글 폰트 관련:
%%% [dvips] : unfonts-type1 (ut**)
%%% pdftex : unfonts-type1 (ut**)
%%% latex -> dvipdfmx : unfonts (un**)
%%%
\newif\ifnokorean\nokoreanfalse
\DeclareOption{nokorean}{\nokoreantrue}
\newif\iftwosidedoc\twosidedocfalse
\DeclareOption{twoside}{\twosidedoctrue}
\newif\ifopenrightdoc\openrightdocfalse
\DeclareOption{openright}{\openrightdoctrue}
\newif\ifkosection\kosectionfalse
\DeclareOption{kosection}{\kosectiontrue}
\newif\ifnobookmarks\nobookmarksfalse
\DeclareOption{nobookmarks}{\nobookmarkstrue}
\newif\if@dvips\@dvipsfalse
\DeclareOption{dvips}{\@dvipstrue}
\DeclareOption*{%
 \PassOptionsToClass{\CurrentOption}{memoir}%
}
\ProcessOptions

%%% dvips
\ifnokorean\else
\if@dvips
 \PassOptionsToPackage{dvips}{memhangul-ucs}
\fi\fi

%%% memoir/memhangul-ucs 로드.
\iftwosidedoc
  \LoadClass[article,openany]{memoir}
\else
  \LoadClass[article,openany,oneside]{memoir}
\fi
\ifopenrightdoc\openright\fi
\ifnokorean\else
  \ifnobookmarks
    \usepackage[nonfrench,interworddefault,hangulpagestyle,gremph]{memhangul-ucs}
  \else
    \usepackage[nonfrench,interworddefault,hangulpagestyle,gremph,pdfbookmark]{memhangul-ucs}
  \fi
\fi
\counterwithout{section}{chapter}

%%% korean fontsettings
\ifnokorean\else
\ifpdf
 \usepackage[ps]{hfontsel}               % ut**를 기본 글꼴로
 \pdfmapfile{+unttf-pdftex-dhucs.map} % 그래도 혹시 모르므로 
%%% dhucs-cmap은 여기서 로드한다.
 \usepackage{dhucs-cmap}
% \input glyphtounicode\pdfgentounicode=1
\else
 \if@dvips
  \usepackage[ps]{hfontsel} % ut**를 기본 글꼴로
 \else
  \usepackage{hfontsel}      % 아무 옵션도 없다면 un**
\fi\fi
\fi

%%% footnote setting
%%% 99)에 해당하는 박스 길이를 구한 다음
\newsavebox\mytmpbox\sbox\mytmpbox{\footnotesize 99)\ }
%%% 각주 번호 박스를 길이에 대하여 오른쪽 정렬함. 두 자리
%%% 각주 번호 기준으로 오른쪽 정렬되도록 만든다.
\footmarkstyle{\makebox[\wd\mytmpbox][r]{#1)\ }}
\setlength\footmarksep{\wd\mytmpbox}
\setlength\footmarkwidth{0pt}
\setlength\footparindent{0pt}
\ifnokorean\else
\SetFnmark{\textsuperscript}{\textsuperscript{)}}
\fi
%%% footnotes and floats. codes from memmanadd.pdf
\renewcommand*{\footnoterule}{\kern-3pt\vfill
  \hrule width 0.4\columnwidth \kern 2.6pt}
\setlength{\skip\footins}{1.3\onelineskip}

%%% subsection까지 항번을 붙이고 toc에 두자.
\maxtocdepth{subsection}
\maxsecnumdepth{subsection}

%%% toc 등의 레이아웃.
\renewcommand\chaptitlefont{\Large\bfseries}
\renewcommand\printchapternonum{}
\renewcommand\printchaptertitle[1]{\chaptitlefont #1}
\renewcommand\afterchapskip{\onelineskip}
\renewcommand\beforechapskip{1.5\onelineskip}

\renewcommand\cftsectionindent{0pt}
\ifnokorean\else
\renewcommand\cftsectionnumwidth{1.8em}
\renewcommand\cftsubsectionindent{1.8em}
\renewcommand\cftsubsectionnumwidth{2.5em}
\fi
\let\cftchapterindent\cftsectionindent
\let\cftchapternumwidth\cftsectionnumwidth
\let\cftbeforechapterskip\cftbeforesectionskip

\renewcommand\cftsectionpresnum{\hfill}
\renewcommand\cftsectionaftersnum{\hskip.8em}

%%% kscntformat
%%% HLaTeX의 \kscntformat 명령을 흉내냄
%%% \kscntformat{section}{제}{절} 형식으로 쓴다.
\newsavebox{\tmp@XXbox}
\newdimen\tmp@XXdim
\def\kscntformat#1#2#3{%
	\sbox{\tmp@XXbox}{#2\number\c@section#3}%
	\setlength\tmp@XXdim{\wd\tmp@XXbox}\advance\tmp@XXdim by1em%
	\expandafter\def\csname the#1\endcsname{#2\number\c@section#3}%
	\expandafter\renewcommand\csname cft#1numwidth\endcsname{\tmp@XXdim}%
	\expandafter\renewcommand\csname cft#1presnum\endcsname{}%
	\expandafter\renewcommand\csname cft#1aftersnum\endcsname{}%
}

\ifnokorean\else
\ifkosection
\kscntformat{section}{제\:}{\:절}
\renewcommand\thesubsection{\arabic{section}.\arabic{subsection}}
\fi\fi

%%% misc settings
\raggedbottom
\ifnokorean
\renewcommand\sectionmark[1]{\markboth{\thetitle}{#1}}
\else
\renewcommand\sectionmark[1]{\PrerenderUnicode{\thetitle#1}\markboth{\thetitle}{#1}}
\fi
%\renewcommand\subsectionmark[1]{\markright{#1}}
\ifnokorean
\newcommand*\MarkDocTitle{\markboth{\thetitle}{}}
\else
\newcommand*\MarkDocTitle{\PrerenderUnicode{\thetitle}\markboth{\thetitle}{}}
\fi

%%% for bookmarks and hyperref
\ifpdf
\ifnobookmarks
  \usepackage[pdftex,bookmarks=false]{hyperref}
\fi\else
  \ifnobookmarks
  \usepackage[bookmarks=false]{hyperref}
\fi\fi

%%% \engtxt를 일일이 쓰기 귀찮고 space가 하나밖에 없을 때
%%% 쓰기 위한 \ensp 매크로.
\newskip\@ensp
\@ensp=.331em plus .02em minus .01em
\def\ensp{\hskip\@ensp}

%%% article의 pagestyle 기본값은 plain임.
\pagestyle{plain}

%%% 2006/09/01 \title, \author 문제. reported by IsCho
\AtBeginDocument{%
 \@ifundefined{thetitle}{\title{}}{\relax}
 \@ifundefined{theauthor}{\author{}}{\relax}
}

\endinput
